@@ -88,6 +88,8 @@ c     *      ( pj.code .eq. ktriton .or. pj.code .eq. kdeut) ) then
            call cphits(pj, ia, iz, TargetXs, a, ntp)
         elseif(ActiveMdl .eq. 'qgsjet2') then
            call cQGSjet(pj, ia, iz, a, ntp)
+        elseif(ActiveMdl .eq. 'epos') then
+           call ceposGenOneEvent(a, ntp)
         elseif(ActiveMdl .eq. 'gheisha' .and.
      *        pj.code .eq. kgnuc  .and. (pj.subcode .eq. 2 .or.
      *        pj.subcode .eq. 3) ) then
