@@ -234,9 +234,9 @@ c                move pion
              ntp = 1
          else
 c            ____________________________________________
-             write(msg,*) ' failed to adjust  missing mass=',
-     *       Missingp.mass, ' into pion mass. consult k.k'
-             call cerrorMsg(msg, 1)
+             write(0,*) ' failed to adjust  missing mass=',
+     *       Missingp.mass, ' into pion mass. '
+c             call cerrorMsg(msg, 1)
 c            ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
              ntp = 0
              icon = 1
