@@ -42,12 +42,29 @@ c
       NoOfMdls = MaxIntMdls
  10   continue
       do i = 1, NoOfMdls-1
-         if(InteErg(i) .ge. InteErg(i+1)) then
+!         if(InteErg(i) .ge. InteErg(i+1)) then
+         if(InteErg(i) > InteErg(i+1)) then  ! v7.633
 c                 energy region invalid
             call cerrorMsg(
      *           'IntModle is invalid; energy region not ascending', 1)
             call cerrorMsg(IntModel, 0)
+         elseif(InteErg(i) == InteErg(i+1)) then ! v7.633
+!             a model written between(i) and (i+1)
+!             will not be used explicitly but initialization
+!             is tried. It might be used as a rescuee when a
+!             some model cannot cope with a specific particle.
+            ! issue some message
+            write(0,*) '================================='
+            write(0,*)
+     *        i,'-th and ',i+1,'-th energy in IntModle are same' 
+            write(0,*) 'The model specified is',ModelList(i+1), '.'
+            write(0,*) 'It will not be used explicitly but might be'
+            write(0,*) 'used when some model needs help for a '
+            write(0,*) 'specific particle. dpmjet3 is a good  ' 
+            write(0,*) 'candidate of such a model'
+            write(0,*) '================================='
          endif
+
       enddo
 c         exam models
       do i = 1, NoOfMdls
