@@ -25,14 +25,17 @@
       case('phits')
          if(  pj.code == kpion .and. pj.charge == 0) then
             icon = -1
-         elseif( pj.code == kkaon .and. pj.charge == 0 ) then
+!         elseif( pj.code == kkaon .and. pj.charge == 0 ) then
+         elseif( pj.code == kkaon ) then ! from v 7.633  
+                           ! at cfixModel, phits might be
+                           ! already not assigned
             icon  = -1
          elseif( pj.code >=  klambda .or. pj.code == kdmes ) then
             icon = -1
          endif
       case('jam') 
          if(  pj.code == kpion .and. pj.charge == 0) then
-            icon = -1
+!            icon = -1
 
 !         elseif( pj.code == kkaon .and. pj.charge == 0 ) then
 !            original jam should be ok
