@@ -241,6 +241,9 @@ c
       record /coord/ xyz1, xyz2, dircos, unitv
 
       loc = TrackBefMove.where
+c///////////
+      write(0,*) ' loc =', loc
+c//////////
 c
 c           observation plane is perpendicular to primary
 c           convert coord into 1ry system
@@ -315,7 +318,12 @@ c                 escape from side 6
             endif
          endif
       endif
-
+c/////////////
+      write(0,*) ' see upper=',seeupper, ' cross=',cross
+      write(0,*) ' where=', MovedTrack.where
+      write(0,*) ' MoveStat=',MoveStat
+      write(0,*) ' BorderL=',BorderL, 'BorderH=',BorderH
+c/////////////
       if(.not. cross ) then
 c     *      .and. MovedTrack.pos.height .gt. BorderHeightL  
 c     *     .and.    MovedTrack.pos.height .lt. BorderHeightH ) then
@@ -326,6 +334,9 @@ c         get length to the  x-ing point
      *                TrackBefMove.pos.xyz.z,
      *               unitv.r(1), unitv.r(2), unitv.r(3),
      *               BorderHeightL+Eradius,  leng, icon)
+c/////////////
+         write(0,*) ' 1 leng=',leng, ' icon=',icon
+c//////////////
          leng = leng + 0.01d0
 c         MovedTrack.where  = NoOfSites + 1
       elseif( cross .and. MoveStat .eq. BorderH ) then
@@ -334,6 +345,9 @@ c         get length to the  x-ing point
      *                TrackBefMove.pos.xyz.z,
      *               unitv.r(1), unitv.r(2), unitv.r(3),
      *               BorderHeightH+Eradius,  leng, icon)
+c//////////
+         write(0,*) ' borderH leng=',leng, 'icon=',icon
+c//////////////
          leng = leng + 0.01d0
       else
 c           
@@ -344,6 +358,9 @@ c           get length to the x-ing point
          else
             leng = (ObsSites(loc).zpl - xyz1.r(3))/dircos.r(3)
          endif
+c/////////
+         write(0,*) ' 3  leng=',leng
+c//////////
          leng = abs(leng)
 c         leng = leng + abs(0.01d0/dircos.r(3))
          leng = leng + 0.01d0
@@ -360,6 +377,9 @@ c            must find shorter x-ing point
      *                TrackBefMove.pos.xyz.z,
      *               unitv.r(1), unitv.r(2), unitv.r(3),
      *               BorderHeightH+Eradius,  leng2, icon)
+c///////////
+            write(0,*) ' 3 leng2=',leng2, ' icon=',icon
+c/////////////
             if( leng2 .lt. leng ) then
                leng = leng2
                MoveStat = BorderH
@@ -371,6 +391,9 @@ c            must find shorter x-ng point
      *                TrackBefMove.pos.xyz.z,
      *               unitv.r(1), unitv.r(2), unitv.r(3),
      *               BorderHeightL+Eradius,  leng2, icon)
+c///////////
+            write(0,*) ' 4 leng2=',leng2, ' icon=',icon
+c/////////////
             if( leng2 .lt. leng ) then
                leng = leng2
                MoveStat = BorderL
