@@ -4,6 +4,14 @@
 #include  "Ztrackv.h"
       integer i
       character*70 msg
+
+c///////////////////
+c              to see possibility of photon projectile 
+c              with Primary is 'gamma' ;    see last
+c              part of this file.
+c      call cpredpmjet( MovedTrack.p,  Pwork, Nproduced)
+c//////////
+
       if(IntInfArray(ProcessNo).process .eq. 'pair') then
          call cpair
       elseif(IntInfArray(ProcessNo).process .eq. 'compt') then
@@ -204,66 +212,52 @@ c     ***********
       subroutine cphotop
 c     ***********
       implicit none
-c----      include '../Particle/Zcode.h'
 #include  "Zcode.h"
-c----      include 'Ztrack.h'
 #include  "Ztrack.h"
-c----      include 'Ztrackv.h'
 #include  "Ztrackv.h"
+#include  "Ztrackp.h"
 c
-c      record /track/aTrack
-c      integer i
 c
-c///////////////
-      real*8 sum
-      integer i
-      record /ptcl/work(3000)
-c////////////
       integer ngen
+      character(8):: whichcode 
+      Nproduced = 0
+      if( HowPhotoP == 0 ) then  ! will not happen
+         ngen = 1
+         Pwork(Nproduced+1) =  MovedTrack.p
+      elseif( HowPhotoP == 1 ) then
+         whichcode = "sofia"
+      elseif( HowPhotoP == 2 ) then
+         if( MovedTrack.p.fm.p(4) < 2.5 )  then
+            whichcode ="current"
+         else
+            whichcode ="sofia"
+         endif
+      elseif( HowPhotoP == 3 ) then
+         if( MovedTrack.p.fm.p(4) < 2.5 )  then
+            whichcode ="sofia"
+         else
+            whichcode ="current"
+         endif
+      elseif( HowPhotoP == 4 ) then
+         whichcode = "current"
+      else
+         write(0,*) 'HowPhotoP =', HowPhotoP, ' invalid '
+         stop
+      endif
 
-      Nproduced = 0  ! in case of Cosmos, this has been done already 
-c//////////////
-c      write(0,*) ' in cphotop; bef cgpHad MoveE=',
-c     *     MovedTrack.p.fm.p(4)
-c//////////
-      call cgpHad(TargetNucleonNo, TargetProtonNo, 
-     *   MovedTrack.p, 2, Pwork(Nproduced+1), ngen)
-c
-c      call cgpHad(TargetNucleonNo, TargetProtonNo, 
-c     *   MovedTrack.p, 2, work, ngen)
-cc      work(1) = MovedTrack.p
-cc      work(1).fm.p(4) = MovedTrack.p.fm.p(4)/2.
-cc      call cmkptc(kelec, regptcl, -1, work(1))
-cc      call ce2p(work(1))
-cc      work(2) = work(1)
-cc      call cmkptc(kelec, antip, 1, work(2))
-cc      call ce2p(work(2))
-cc      ngen =2 
-c///////////////////
-c      write(0,*) ' cgpHad nge=',ngen,' Npro=',Nproduced
-c      do i = 1, ngen
-c         sum = sum + Pwork(Nproduced+i).fm.p(4)
-c      enddo
-c      write(0,*) ' Eg=',MovedTrack.p.fm.p(4), 'out=',sum
-cc      if(ngen .ne. 2 .or. Nproduced .ne. 0) then
-cc         write(0, *) ' nge=',ngen,' Nproduced=',Nproduced
-cc         write(0, *) ' proc=',IntInfArray(ProcessNo).process
-cc         write(0,*) ' parent=',MovedTrack.p.fm.p(4),
-cc     *           ' E1+E2=', work(1).fm.p(4)+work(2).fm.p(4)
-cc         write(0,*) ' muon E=',Pwork(1).fm.p(4)
-cc      endif
-c      do i = 1, ngen
-c         Pwork(i+Nproduced) = work(i)
-c      enddo
-c/////////////////////
+      if( whichcode == "sofia" ) then
+         call csofia( TargetNucleonNo, TargetProtonNo, 
+     *      MovedTrack.p, Pwork(Nproduced+1), ngen)
+      elseif( whichcode == "current" ) then
+         call cgpHad(TargetNucleonNo, TargetProtonNo, 
+     *        MovedTrack.p, Pwork(Nproduced+1), ngen)
+      else
+         write(0,*) ' setting mistake of  whichcode=',
+     *    whichcode, ' in cphotop'
+         stop
+      endif
       Nproduced = Nproduced + ngen
          
-c     
-c      aTrack = MovedTrack
-c      do i = 1, Nproduced
-c         aTrack.p = Pwork(i)
-c         call cpush(aTrack)
-c      enddo
       end
 c     ****************
       subroutine ccohs
@@ -384,3 +378,19 @@ c
       Nproduced = Nproduced + 1
       Pwork(Nproduced) = aTrack.p
       end
+      
+c/////////////
+      subroutine cpredpmjet(pj,  a, ntp)
+#include  "Zair.h"
+#include "Zptcl.h"
+      record /ptcl/  pj
+      integer ntp
+      record /ptcl/ a(*)
+      TargetNucleonNo=14
+      TargetProtonNo= 7 
+      call cdpmjet( pj, TargetNucleonNo, TargetProtonNo,
+     *   a, ntp)
+      write(0,*) ' ntp =',ntp
+      stop
+      end
+c/////////////
