@@ -611,7 +611,7 @@ c      and icon =1  is made. else icon = 0
 
       icon = 0
       if(atrack.p.code .eq. kgnuc) then
-         call cfixModel(atrack)
+         call cfixModel(atrack.p)
          if(ActiveMdl .eq. 'dpmjet3' .and. 
      *      atrack.p.subcode .gt. 18) then
 c/////            icon = 1 ///// 
