@@ -64,6 +64,9 @@ c              old def
          real*8 Elund3   !2 obsolete  (from v6.0).
 	 real*8  Efermi  !2  If Kinetic E $<$ Efermi, Fermi Momentum is considered for 
                          ! Nucleus target.
+         integer:: DoNPadjust !2 0(Default):  0--> original is used
+                    ! 1--> do adustement of  # of n,p  for phits model
+                    !  when projectile is  p or n and target A > 10.
 
 c	<-)     -----------------------------
 c            next are not input parameters.
@@ -75,6 +78,7 @@ c            next are not input parameters.
 
         common /Zevhnp/ Cepic0, Cekaon, Ceneuc, Mudirp, Kpilog, Eta2Pi0,
      *         Kpicns,  Efermi, Elund, Elund2, Elund3, SucPw, MulLow, 
-     *         LundPara(10), SucInt
+     *         LundPara(10), SucInt, DoNPadjust
+!!     *         LundPara(10), SucInt
         common /Zevhnc/RegMdls, InclusiveFile, IntModel
 
