@@ -16,10 +16,10 @@ c	(->	--------------------------------------------
                               !  inclined trajectory by using numerical integration.
         logical IncMuonPolari  !1  if T, consider muon polarization
         integer HowPhotoP      !2  if 0--> no photo hadron prod.
-                               !      1--> by using sofia
-                               !      2--> old method using vector meson
-                               !      3--> below Eg<2.5GeV,  same as 1.
-                               !      4     Eg>2.5GeV   same as 2.
+	 !      1--> Sofia at all E
+	 !      2--> Exp. data < 2.5 GeV ; Sofia > 2.5GeV
+	 !      3--> Sofia < 2.5GeV;  (rho, omega, phi) or pi0 or pi+/- at current model
+         !      4--> Exp. data < 2.5GeV   //
          integer  PhitsXs !2 when phits is used, specify the Xsection to be used.
                 !  D=0.   Use cosmos xsection				
                 !  bit 1--> for p,n use phits xs (last bit is bit 1) (btest(..,0)-->T
